==> ejc-proequipmentp-impl-3.0.0-20220719.064231-192-sources.jar: com/ejianc/business/asset/controller/AssetAmortizeController.java <==
package com.ejianc.business.asset.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.asset.service.IAmortizeSetService;
import com.ejianc.business.asset.service.IAssetRecordService;
import com.ejianc.business.asset.vo.AssetAmortizeDetailVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.framework.core.kit.collection.ListUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

import com.ejianc.business.asset.bean.AssetAmortizeEntity;
import com.ejianc.business.asset.service.IAssetAmortizeService;
import com.ejianc.business.asset.vo.AssetAmortizeVO;

/**
 * 固定资产摊销
 *
 * @author generator
 */
@Controller
@RequestMapping("assetAmortize")
@Api(value = "固定资产摊销", tags = {"固定资产摊销"})
public class AssetAmortizeController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "ASSET_AMORTIZE_CODE";

    @Autowired
    private IAssetAmortizeService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IAssetRecordService assetRecordService;

    @Autowired
    private IAmortizeSetService amortizeSetService;


    @RequestMapping(value = "/test", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Boolean> test() {
        AssetAmortizeVO assetAmortizeVO = new AssetAmortizeVO();
        assetAmortizeVO.setId(1L);
        AssetAmortizeDetailVO assetAmortizeDetailVO = new AssetAmortizeDetailVO();
        assetAmortizeDetailVO.setAssetName("ceshi");
        assetAmortizeDetailVO.setEquipmentName("测试啊");
        assetAmortizeVO.setDetailList(Arrays.asList(assetAmortizeDetailVO));
        return CommonResponse.success("查询详情数据成功！", assetRecordService.saveRecord(assetAmortizeVO));
    }

    @ApiOperation("新增或者修改")
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<AssetAmortizeVO> saveOrUpdate(@ApiParam(name = "saveOrUpdateVO", required = true) @RequestBody AssetAmortizeVO saveOrUpdateVO) {
        AssetAmortizeEntity entity = BeanMapper.map(saveOrUpdateVO, AssetAmortizeEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        service.saveOrUpdate(entity, false);
        AssetAmortizeVO vo = BeanMapper.map(entity, AssetAmortizeVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }


    @ApiOperation("查询详情")
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<AssetAmortizeVO> queryDetail(@RequestParam Long id) {
        AssetAmortizeEntity entity = service.selectById(id);
        AssetAmortizeVO vo = BeanMapper.map(entity, AssetAmortizeVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }


    @ApiOperation("批量删除单据")
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<AssetAmortizeVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (AssetAmortizeVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(AssetAmortizeVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }


    @ApiOperation("查询列表")
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<AssetAmortizeVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("billCode", "orgName", "employeeName", "categoryName"));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if (5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<AssetAmortizeEntity> page = service.queryPage(param, false);
        IPage<AssetAmortizeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), AssetAmortizeVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    @ApiOperation("导出")
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<AssetAmortizeEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("AssetAmortize-export.xlsx", beans, response);
    }


    @ApiOperation("参照")
    @RequestMapping(value = "/refAssetAmortizeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<AssetAmortizeVO>> refAssetAmortizeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                       String condition,
                                                                       String searchObject,
                                                                       String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<AssetAmortizeEntity> page = service.queryPage(param, false);
        IPage<AssetAmortizeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), AssetAmortizeVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }


    /**
     * @param orgId
     * @description: 查上次摊销周期
     * @return: com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     * @author songlx
     * @date: 2022/7/12
     */
    @RequestMapping(value = "/getLastAmortizeDate", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> getLastAmortizeDate(Long orgId, Long billId) {
        QueryWrapper<AssetAmortizeEntity> assetAmortizeEntityQueryWrapper = new QueryWrapper<>();
        assetAmortizeEntityQueryWrapper.select("date_format( MAX( amortize_date ), '%Y-%m' ) lastDate");
        assetAmortizeEntityQueryWrapper.eq("org_id", orgId);
        assetAmortizeEntityQueryWrapper.eq(billId != null, "id", billId);
        Map<String, Object> map = service.getMap(assetAmortizeEntityQueryWrapper);
        Object lastDate = map != null ? map.get("lastDate") : null;
        String lastAmortizeDate = lastDate != null ? String.valueOf(lastDate) : null;
        return CommonResponse.success("查询上次摊销周期成功！", lastAmortizeDate);
    }


    /**
     * @param assetAmortizeVO
     * @description: 根据材料清单获取本次摊销金额
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.asset.vo.AssetAmortizeVO>
     * @author songlx
     * @date: 2022/7/15
     */
    @ApiOperation("根据材料清单获取本次摊销金额")
    @RequestMapping(value = "/getAmortizeMny", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<AssetAmortizeVO> getAmortizeMny(@ApiParam(name = "assetAmortizeVO", required = true) @RequestBody AssetAmortizeVO assetAmortizeVO) {
        Date lastAmortizeDate = assetAmortizeVO.getLastAmortizeDate();
        Date amortizeDate = assetAmortizeVO.getAmortizeDate();

        List<AssetAmortizeDetailVO> detailList = assetAmortizeVO.getDetailList();
        if(CollectionUtils.isEmpty(detailList)){
            return CommonResponse.success("未选择在场设备！", assetAmortizeVO);
        }
        // 获取设备的摊销设置
        amortizeSetService.getSet(detailList);

        return CommonResponse.success("根据材料清单获取本次摊销金额！", assetAmortizeVO);
    }

}

==> ejc-proequipmentp-impl-3.0.0-20220720.025050-195-sources.jar: com/ejianc/business/asset/controller/AssetAmortizeController.java <==
package com.ejianc.business.asset.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.asset.service.IAmortizeSetService;
import com.ejianc.business.asset.service.IAssetRecordService;
import com.ejianc.business.asset.vo.AssetAmortizeDetailVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.framework.core.kit.collection.ListUtil;
import org.apache.commons.lang3.StringUtils;
import org.joda.time.Months;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.time.LocalDate;
import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

import com.ejianc.business.asset.bean.AssetAmortizeEntity;
import com.ejianc.business.asset.service.IAssetAmortizeService;
import com.ejianc.business.asset.vo.AssetAmortizeVO;

/**
 * 固定资产摊销
 *
 * @author generator
 */
@Controller
@RequestMapping("assetAmortize")
@Api(value = "固定资产摊销", tags = {"固定资产摊销"})
public class AssetAmortizeController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "ASSET_AMORTIZE_CODE";

    @Autowired
    private IAssetAmortizeService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IAssetRecordService assetRecordService;

    @Autowired
    private IAmortizeSetService amortizeSetService;


    @RequestMapping(value = "/test", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Boolean> test() {
        AssetAmortizeVO assetAmortizeVO = new AssetAmortizeVO();
        assetAmortizeVO.setId(1L);
        AssetAmortizeDetailVO assetAmortizeDetailVO = new AssetAmortizeDetailVO();
        assetAmortizeDetailVO.setAssetName("ceshi");
        assetAmortizeDetailVO.setEquipmentName("测试啊");
        assetAmortizeVO.setDetailList(Arrays.asList(assetAmortizeDetailVO));
        return CommonResponse.success("查询详情数据成功！", assetRecordService.saveRecord(assetAmortizeVO));
    }

    @ApiOperation("新增或者修改")
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<AssetAmortizeVO> saveOrUpdate(@ApiParam(name = "saveOrUpdateVO", required = true) @RequestBody AssetAmortizeVO saveOrUpdateVO) {
        AssetAmortizeEntity entity = BeanMapper.map(saveOrUpdateVO, AssetAmortizeEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        service.saveOrUpdate(entity, false);
        AssetAmortizeVO vo = BeanMapper.map(entity, AssetAmortizeVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }


    @ApiOperation("查询详情")
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<AssetAmortizeVO> queryDetail(@RequestParam Long id) {
        AssetAmortizeEntity entity = service.selectById(id);
        AssetAmortizeVO vo = BeanMapper.map(entity, AssetAmortizeVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }


    @ApiOperation("批量删除单据")
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<AssetAmortizeVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (AssetAmortizeVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(AssetAmortizeVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }


    @ApiOperation("查询列表")
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<AssetAmortizeVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("billCode", "orgName", "employeeName", "categoryName"));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if (5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<AssetAmortizeEntity> page = service.queryPage(param, false);
        IPage<AssetAmortizeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), AssetAmortizeVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    @ApiOperation("导出")
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<AssetAmortizeEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("AssetAmortize-export.xlsx", beans, response);
    }


    @ApiOperation("参照")
    @RequestMapping(value = "/refAssetAmortizeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<AssetAmortizeVO>> refAssetAmortizeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                       String condition,
                                                                       String searchObject,
                                                                       String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<AssetAmortizeEntity> page = service.queryPage(param, false);
        IPage<AssetAmortizeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), AssetAmortizeVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }


    /**
     * @param orgId
     * @description: 查上次摊销周期
     * @return: com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     * @author songlx
     * @date: 2022/7/12
     */
    @RequestMapping(value = "/getLastAmortizeDate", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> getLastAmortizeDate(Long orgId, Long billId) {
        QueryWrapper<AssetAmortizeEntity> assetAmortizeEntityQueryWrapper = new QueryWrapper<>();
        assetAmortizeEntityQueryWrapper.select("date_format( MAX( amortize_date ), '%Y-%m' ) lastDate");
        assetAmortizeEntityQueryWrapper.eq("org_id", orgId);
        assetAmortizeEntityQueryWrapper.eq(billId != null, "id", billId);
        Map<String, Object> map = service.getMap(assetAmortizeEntityQueryWrapper);
        Object lastDate = map != null ? map.get("lastDate") : null;
        String lastAmortizeDate = lastDate != null ? String.valueOf(lastDate) : null;
        return CommonResponse.success("查询上次摊销周期成功！", lastAmortizeDate);
    }


    /**
     * @param assetAmortizeVO
     * @description: 根据材料清单获取本次摊销金额
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.asset.vo.AssetAmortizeVO>
     * @author songlx
     * @date: 2022/7/15
     */
    @ApiOperation("根据材料清单获取本次摊销金额")
    @RequestMapping(value = "/getAmortizeMny", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<AssetAmortizeVO> getAmortizeMny(@ApiParam(name = "assetAmortizeVO", required = true) @RequestBody AssetAmortizeVO assetAmortizeVO) {
        Date amortizeDate = assetAmortizeVO.getAmortizeDate();

        List<AssetAmortizeDetailVO> detailList = assetAmortizeVO.getDetailList();
        if(CollectionUtils.isEmpty(detailList)){
            return CommonResponse.success("未选择在场设备！", assetAmortizeVO);
        }
        // 获取设备的摊销设置
        service.getAmortizeSet(detailList);
        //计算本次摊销金额
        service.caclAmortizeMny(detailList, amortizeDate);
        return CommonResponse.success("根据材料清单获取本次摊销金额！", assetAmortizeVO);
    }


}
